Module blaxel.core.client.models.resource_log_chart
===================================================

Classes
-------

`ResourceLogChart(count: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, debug: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, error: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, fatal: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, info: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, timestamp: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, trace: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, unknown: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, warning: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   Chart for a resource log
    
    Attributes:
        count (Union[Unset, int]): Count of the log
        debug (Union[Unset, int]): Debug count of the log
        error (Union[Unset, int]): Error count of the log
        fatal (Union[Unset, int]): Fatal count of the log
        info (Union[Unset, int]): Info count of the log
        timestamp (Union[Unset, str]): Timestamp of the log
        trace (Union[Unset, int]): Trace count of the log
        unknown (Union[Unset, int]): Unknown count of the log
        warning (Union[Unset, int]): Warning count of the log
    
    Method generated by attrs for class ResourceLogChart.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `count: blaxel.core.client.types.Unset | int`
    :

    `debug: blaxel.core.client.types.Unset | int`
    :

    `error: blaxel.core.client.types.Unset | int`
    :

    `fatal: blaxel.core.client.types.Unset | int`
    :

    `info: blaxel.core.client.types.Unset | int`
    :

    `timestamp: blaxel.core.client.types.Unset | str`
    :

    `trace: blaxel.core.client.types.Unset | int`
    :

    `unknown: blaxel.core.client.types.Unset | int`
    :

    `warning: blaxel.core.client.types.Unset | int`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :